@@ -13,7 +13,7 @@ from .FunctionGUI import (
     Run,
     BulleanVar,
     ChexBox,
-    Add,
+    add,
     Design
 
 )
